@@ -248,7 +248,7 @@ def init_runestone(yes, defaults):
     init_template_arguments(template_dir, defaults, 'runestone')
 
 
-def build_or_autobuild(cmd_name, port=None, sphinx_build=False, sphinx_autobuild=False, project_type='runestone'):
+def build_or_autobuild(cmd_name, port=None, sphinx_build=False, sphinx_autobuild=False, project_type='runestone', sphinx_builder = 'html'):
     path = project_path()
     if not path:
         raise click.ClickException(
@@ -260,23 +260,32 @@ def build_or_autobuild(cmd_name, port=None, sphinx_build=False, sphinx_autobuild
     if not buildPath.exists:
         os.makedirs(buildPath)
     args = []
+    srcdir = os.path.realpath(paver_options.build.sourcedir)
+    outdir = os.path.realpath(paver_options.build.builddir)
+    doctreesdir = outdir + './doctrees'
+    if sphinx_builder == 'petlja_builder':
+        rootdir = outdir + '/bc_html'
+    else:
+        rootdir = outdir
+
+    if not os.path.exists(rootdir + '/course'):
+        os.makedirs(rootdir + '/course')
+    if project_type != 'runestone':
+        shutil.copyfile('course.json', rootdir + '/course/course.json')
 
     if sphinx_autobuild:
-        srcdir = os.path.realpath(paver_options.build.sourcedir)
-        outdir = os.path.realpath(paver_options.build.builddir)
         if not os.path.exists(outdir):
             os.makedirs(outdir)
         server = Server()
         builder = get_builder(
-            server.watcher, ['-b', 'html', '-d', './_build/doctrees', '-c', '.', srcdir, outdir], pre_build_commands=[]
+            server.watcher, ['-b', sphinx_builder , '-d', doctreesdir, '-c', '.', srcdir, outdir], pre_build_commands=[]
         )
-
         server.watch(srcdir, builder, ignore=[])
         server.setHeader('Access-Control-Allow-Origin', '*')
         server.setHeader('Access-Control-Allow-Methods', '*')
 
         server.serve(port=port, host="127.0.0.1",
-                     root=outdir, open_url_delay=5)
+                     root=rootdir, open_url_delay=5)
 
     if sphinx_build:
         if not os.path.exists(os.path.join(path, '_build')) and project_type == 'course':
@@ -284,20 +293,22 @@ def build_or_autobuild(cmd_name, port=None, sphinx_build=False, sphinx_autobuild
         build_module = "sphinx.cmd.build"
         args.append('-a')
         args.append('-E')
-        args.append('-b html')
+        args.append(f'-b "{sphinx_builder}"')
         args.append(f'-c "{paver_options.build.confdir}"')
-        args.append(f'-d "{paver_options.build.builddir}/doctrees"')
+        args.append(f'-d "{doctreesdir}"')
         for k, v in paver_options.build.template_args.items():
             args.append(f'-A "{k}={v}"')
         args.append(f'"{paver_options.build.sourcedir}"')
-        args.append(f'"{paver_options.build.builddir}"')
+        args.append(f'"{outdir}"')
 
         sh(f'"{sys.executable}" -m {build_module} ' + " ".join(args))
+    
 
 
 @main.command()
 @click.option("--port", "-p", default=8000, type=int, help="HTTP port numpber (default 8000)")
-def preview(port):
+@click.option("--builder", "-b", default="html", type=str, help="Shpinx builder that should be used")
+def preview(port, builder):
     """
     Build and preview the Runestone project in browser
     """
@@ -310,9 +321,9 @@ def preview(port):
                 watch_server([os.path.realpath('_sources'),
                               os.path.realpath('_images')])
                 build_or_autobuild(
-                    "preview", port=port, sphinx_build=True, project_type=data["project_type"])
+                    "preview", port=port, sphinx_build=True, project_type=data["project_type"], sphinx_builder =builder)
                 build_or_autobuild(
-                    "preview", port=port, sphinx_autobuild=True, project_type=data["project_type"])
+                    "preview", port=port, sphinx_autobuild=True, project_type=data["project_type"], sphinx_builder = builder)
             else:
                 build_or_autobuild("preview", port=port, sphinx_build=True)
                 build_or_autobuild("preview", port=port, sphinx_autobuild=True)
@@ -488,7 +499,7 @@ def create_course():
                         archived_lessons.append(archived_lesson_guid)
 
                 for i, lesson in enumerate(data['lessons'], start=1):
-                    active_activies = []
+                    active_activities = []
                     archived_activities = []
                     order_prefix_lesson = str(i)+'_'
                     lesson_line = lesson['__line__']
@@ -547,11 +558,11 @@ def create_course():
                                 continue
 
                             else:
-                                active_activies.append(Activity(
+                                active_activities.append(Activity(
                                     activity_type, activity_title, activity_src, activity_guid, activity_description, lesson_nbsrc))
 
                     active_lessons.append(
-                        Lesson(title, folder, guid, description, archived_activities, active_activies))
+                        Lesson(title, folder, guid, description, archived_activities, active_activities))
 
             course = Course(courseId, lang, title_course, longDesc, shortDesc, willLearn,
                             requirements, toc, external_links, archived_lessons, active_lessons)
@@ -630,6 +641,8 @@ def print_error(error, first_build):
 def template_toc(course):
     with open('course.json', mode='w', encoding='utf8') as file:
         file.write(json.dumps(course.to_dict()))
+    with open('overide.json', mode='w', encoding='utf8') as file:
+        file.write(json.dumps(course.metadata_to_dict()))
 
 
 def create_intermediate_folder(course, path, intermediatPath):
@@ -650,7 +663,7 @@ def create_activity_RST(course, index, path, intermediatPath):
                              encoding='utf-8')
         section_index.write(rst_title(lesson.title))
         section_index.write(_INDEX_TEMPLATE.format(1))
-        for activity in lesson.active_activies:
+        for activity in lesson.active_activities:
             if activity.type in ['reading', 'quiz']:
                 if activity.get_src_type() == 'rst':
                     section_index.write(' '*4+activity.src+'\n')
