@@ -4,7 +4,7 @@ $.i18n().load({
         "flag_title": "Опције",
         "text_title": "Тест текст",
         "button_text": "Прикажи решење",
-        "button_test" : "Упореди решење",
+        "button_test" : "Упореди са решењем",
         "correct": "Тачно",
         "incorrect" : "Нетачно",
     }
